// Copyright (C) 2019, …
// Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
// German Aerospace Center
//
// Institut fuer Flugfuehrung/Institute of Flight Guidance
// Tel. +49 531 295 2500, Fax: +49 531 295 2501
// WWW: http://www.bs.dlr.de/FL/
//
// These coded instructions, statements, and computer programs contain
// unpublished proprietary information of the German Aerospace Center
// and are protected by the copyright law. They may not be disclosed to
// third parties or copied or duplicated in any form,in whole or in part,
// without the prior written consent of the German Aerospace Center


/*!
\file  googleTestEmulation.h
\brief emulates some makros of the google test suite, if that is not available

\author Hartmut Helmke (HHe)

\date 2019-10-06 HHe : first version
\date 2019-11-04 HHe: String parameter in makro is with # and not with ##
                      Makro RETURN_TRUE_IF_NOT_GOOGLE_TEST is new
\date 2019-11-08 HHe: Replacing additional ## by #

*/

#ifndef googleTestEmulation_HEADER
#define googleTestEmulation_HEADER
#pragma once


#ifndef WITHOUT_4D_CARMA_ENVIRONMENT

#   define RETURN_TRUE_IF_NOT_GOOGLE_TEST


#define CATCH_EXCEPTION_AND_RETURN_OR_THROW(ex) \
   catch (ex & e)                               \
      {                                         \
      throw e;                                  \
      }


#define TEST_DISABLE(className, t) TEST(className, DISABLED_##t)

#else

# include <iostream>
# include <cmath>
//#include "disable_warnings_google_tests_vs2019.h"
#define TEST(a, b) bool b()

#define RETURN_TRUE_IF_NOT_GOOGLE_TEST {return true;}

#define CATCH_EXCEPTION_AND_RETURN_OR_THROW(ex) \
   catch (ex &)                                 \
      {                                         \
      return false;                             \
      }

#define TEST_DISABLE(className, testName) TEST(className, testName)

#define EXPECT_EQ(r, e) \
       if ((r) != (e) ) {\
             std::cerr << "Test failed for: " << #r << "==" << #e << std::endl; \
             return false; \
             }
#define EXPECT_NE(r, e) \
       if ((r) == (e) ) {\
             std::cerr << "Test failed for: " << #r << "!=" << #e << std::endl; \
             return false; \
             }

#define ASSERT_NE(r, e) \
       if ((r) == (e) ) {\
             std::cerr << "Test failed for: " << #r << "!=" << #e << std::endl; \
             return false; \
             }

#define EXPECT_NEAR(e, r, tol) \
       if (   (fabs((e)-(r)) > (tol)) ) {\
             std::cerr << "Test failed for: " << #r << "==" << #e << std::endl; \
             return false; \
             }


#endif /*  #ifndef WITHOUT_4D_CARMA_ENVIRONMENT */





#endif /* googleTestEmulation_HEADER */
